@@ -861,6 +861,13 @@ class Application:
                 self.cfg = toml.load(fp)
         except (FileNotFoundError, TypeError):
             pass
+        return path
+
+    def update_config(self, key, value, path=None):
+        path = self.reload_config(path)
+        self.cfg[key] = value
+        with pathlib.Path(path).open("w") as fp:
+            toml.dump(self.cfg, fp)
 
     def add_wrappers(self, *wrappers):
         self.wrappers.extend(wrappers)
