@@ -347,10 +347,12 @@ class Machine(MachineBase):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.nginx_dir = self.system_dir / "nginx"
-        self.python_dir = self.system_dir / "python"
+        # XXX self.nginx_dir = self.system_dir / "nginx"
+        # XXX self.python_dir = self.system_dir / "python"
         self.runinenv = "/home/gaea/runinenv"
         self.projects_dir = self.system_dir / "projects"
+        self.env_dir = "/home/gaea/app"
+        self.run_dir = f"{self.env_dir}/run"
 
     def setup_python(self):
         """
@@ -408,45 +410,72 @@ class Machine(MachineBase):
         self._apt("install -yq nginx libnginx-mod-rtmp")
         self.nginx_conf = "/etc/nginx/nginx.conf"
         self.open_ports(80, 443, 1935)
-        streaming_dir = "/home/gaea/media/streaming"
-        self.run(f"mkdir {streaming_dir} -p")
-        self.run(f"mkdir {streaming_dir}/hls")
-        self.run(f"mkdir {streaming_dir}/rec")
         self.run(
             f"cat > {self.nginx_conf}",
             stdin=str(templates.nginx_conf(self.address, self.onion)),
         )
-        self.run("service nginx restart")
+        self.user = "gaea"
+        streaming_dir = "/home/gaea/app/run/media/streaming"
+        self.run(f"mkdir {streaming_dir} -p")
+        self.run(f"mkdir {streaming_dir}/hls")
+        self.run(f"mkdir {streaming_dir}/rec")
+
+        domain_cnf = configparser.ConfigParser()
+        domain_cnf.optionxform = str
+        domain_cnf["req"] = {
+            "distinguished_name": "req_distinguished_name",
+            "prompt": "no",
+        }
+        domain_cnf["req_distinguished_name"] = {
+            "countryName": "XX",
+            "stateOrProvinceName": "N/A",
+            "localityName": "N/A",
+            "organizationName": "self-signed",
+            "commonName": f"{self.address}: self-signed",
+        }
+        config_output = io.StringIO()
+        domain_cnf.write(config_output)
+        self.run(
+            f"cat > /home/gaea/app/run/ip-selfsigned.cnf",
+            stdin=config_output.getvalue(),
+        )
+        self.run(
+            "sudo openssl req -x509 -nodes -days 365 -newkey rsa:2048"
+            " -keyout /etc/ssl/private/ip-selfsigned.key"
+            " -out /etc/ssl/certs/ip-selfsigned.crt"
+            " -config ip-selfsigned.cnf"
+        )
+        self.user = "root"
         self.generate_dhparam(512)  # NOTE 2048 adds ? minutes
+        self.run("service nginx restart")
 
     def generate_dhparam(self, bits=4096):
         """Generate a unique Diffie-Hellman prime for Nginx."""
-        self.run(f"openssl dhparam -out {self.system_dir}/dhparam.pem {bits}")
+        self.run(f"openssl dhparam -out /etc/nginx/dhparam.pem {bits}")
+        self.run("service nginx restart")
 
-    def setup_app(self, package):
+    def setup_app(self, package, app):
         """Install administrative interface."""
         self.user = "gaea"
         self.run("python3 -m venv app")
-        env_dir = "/home/gaea/app"
-        run_dir = f"{env_dir}/run"
-        self.run(f"mkdir {run_dir}")
+        self.run(f"mkdir {self.run_dir}")
         self.run(f"{self.runinenv} app pip install {package}")
         self.user = "root"
         with self.supervisor(package) as config:
             config["program:app"] = {
                 "autostart": "true",
                 "command": (
-                    f"{self.runinenv} {env_dir} gunicorn {package}:app "
-                    f"-k gevent -w 2 --bind unix:{run_dir}/gunicorn.sock"
+                    f"{self.runinenv} {self.env_dir} gunicorn {app} "
+                    f"-k gevent -w 2 --bind unix:{self.run_dir}/gunicorn.sock"
                 ),
-                "directory": run_dir,
+                "directory": self.run_dir,
                 "stopsignal": "INT",
                 "user": "gaea",
             }
             config["program:queue"] = {
                 "autostart": "true",
-                "command": f"{self.runinenv} {env_dir} bgq run",
-                "directory": run_dir,
+                "command": f"{self.runinenv} {self.env_dir} bgq run",
+                "directory": self.run_dir,
                 "stopsignal": "INT",
                 "user": "gaea",
             }
